@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.62';
+our $VERSION = '0.63';
 
 use Code::TidyAll::Config::INI::Reader 0.44;
 use List::Util 1.45 qw( uniqstr );
@@ -116,6 +116,9 @@ add_packages = Carp Test::Builder
 # prevents very common errors when using a sub in list context to construct a
 # hash and ending up with a missing value or key.
 [-Subroutines::ProhibitExplicitReturnUndef]
+
+# Sometimes I want to write "return unless $x > 4"
+[-ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions]
 EOF
 
 sub before_build {
@@ -281,7 +284,7 @@ Dist::Zilla::Plugin::DROLSKY::TidyAll - Creates default tidyall.ini, perltidyrc,
 
 =head1 VERSION
 
-version 0.62
+version 0.63
 
 =for Pod::Coverage .*
 
